==> rc-ui-lib-0.1.59.tgz: package/es/cascader/__test__/index.spec.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import { sleep } from '../../../tests/utils';
import Icon from '../../icon';
import Cascader from '..';
describe('Cascader', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  var options = [{
    text: '浙江省',
    value: '330000',
    children: [{
      text: '杭州市',
      value: '330100'
    }]
  }, {
    text: '江苏省',
    value: '320000',
    children: [{
      text: '南京市',
      value: '320100'
    }]
  }];
  it('should emit change event when active option changed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var onChange, firstOption, secondOption;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
              options: options,
              onChange: onChange
            }));
            _context.next = 4;
            return sleep();

          case 4:
            wrapper.find('.rc-cascader__option').at(0).simulate('click');
            firstOption = options[0];
            expect(onChange.mock.calls[0][0]).toEqual({
              value: firstOption.value,
              tabIndex: 0,
              selectedOptions: [firstOption]
            });
            _context.next = 9;
            return sleep();

          case 9:
            wrapper.find('.rc-cascader__options').at(1).find('.rc-cascader__option').simulate('click');
            secondOption = options[0].children[0];
            expect(onChange.mock.calls[1][0]).toEqual({
              value: secondOption.value,
              tabIndex: 1,
              selectedOptions: [firstOption, secondOption]
            });

          case 12:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('will not emit onChange event when using disalbed prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    var items, onChange;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            items = [{
              text: '广东省',
              value: '310000',
              children: [{
                text: '深圳市',
                value: '310100'
              }],
              disabled: true
            }];
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
              options: items,
              onChange: onChange
            }));
            _context2.next = 5;
            return sleep();

          case 5:
            wrapper.find('.rc-cascader__option').at(0).simulate('click');
            expect(onChange).not.toHaveBeenCalled();

          case 7:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should emit finish event when all options is selected', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var option, onFinish;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            option = {
              value: '1',
              text: 'foo'
            };
            onFinish = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
              options: [option],
              onFinish: onFinish
            }));
            _context3.next = 5;
            return sleep();

          case 5:
            wrapper.find('.rc-cascader__option').simulate('click');
            expect(onFinish.mock.calls[0][0]).toEqual({
              value: option.value,
              tabIndex: 0,
              selectedOptions: [option]
            });

          case 7:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should emit close event when close icon is clicked', function () {
    var onClose = jest.fn();
    wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
      onClose: onClose
    }));
    wrapper.find(Icon).props().onClick();
    expect(onClose).toHaveBeenCalled();
  });
  it('should not render close icon when closeable is false', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
      closeable: false
    }));
    expect(wrapper.find('.rc-cascader__close-icon').exists()).toBeFalsy();
  });
  it('should change close icon when close-icon prop is string', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
      closeIcon: "success"
    }));
    expect(wrapper.find(Icon).props().name).toEqual('success');
  });
  it('should change close icon when close-icon is ValidElement', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
      closeIcon: /*#__PURE__*/React.createElement(Icon, {
        name: "shop-o"
      })
    }));
    expect(wrapper.find('i.van-icon-shop-o').exists()).toBeTruthy();
  });
  it('should change close icon when close-icon is not ValidElement', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
      closeIcon: 123
    }));
    expect(wrapper.find('i.van-icon-shop-o').exists()).toBeFalsy();
  });
  test('should render title slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
      title: "Custom Title"
    }));
    expect(wrapper.find('.rc-cascader__title').html()).toMatchSnapshot();
  });
  test('should render option correctly when using optionRender prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    var optionItem;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            optionItem = {
              value: '1',
              text: 'foo'
            };
            wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
              options: [optionItem],
              optionRender: function optionRender(_ref5) {
                var option = _ref5.option;
                return "Custom Option ".concat(option.text);
              }
            }));
            _context4.next = 4;
            return sleep();

          case 4:
            expect(wrapper.find('.rc-cascader__option').text()).toEqual('Custom Option foo');

          case 5:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  test('should render option correctly when using defaultValue prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
              options: options,
              defaultValue: ['330000']
            }));
            _context5.next = 3;
            return sleep();

          case 3:
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 4:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  test('should emit onClickTab event correctly', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    var onClickTab;
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            onClickTab = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
              options: options,
              onClickTab: onClickTab
            })); // console.log('====onClickTab-bug===',wrapper.debug());
            // console.log('====onClickTab-html===',wrapper.html());

            _context6.next = 4;
            return wrapper.find('.rc-tab').simulate('click');

          case 4:
            expect(onClickTab).toHaveBeenCalled();

          case 5:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  test('when value change', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
    return _regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
              options: options,
              defaultValue: ['330000']
            }));
            _context7.next = 3;
            return wrapper.setProps({
              value: ['350000']
            });

          case 3:
            expect(toJson(wrapper.html())).toMatchSnapshot();

          case 4:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
});

==> rc-ui-lib-0.2.4.tgz: package/es/cascader/__test__/index.spec.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import { sleep } from '../../../tests/utils';
import Icon from '../../icon';
import Cascader from '..';
describe('Cascader', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  var options = [{
    text: '浙江省',
    value: '330000',
    children: [{
      text: '杭州市',
      value: '330100'
    }]
  }, {
    text: '江苏省',
    value: '320000',
    children: [{
      text: '南京市',
      value: '320100'
    }]
  }];
  it('should emit change event when active option changed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var onChange, firstOption, secondOption;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
              options: options,
              onChange: onChange
            }));
            _context.next = 4;
            return sleep();

          case 4:
            wrapper.find('.rc-cascader__option').at(0).simulate('click');
            firstOption = options[0];
            expect(onChange.mock.calls[0][0]).toEqual({
              value: firstOption.value,
              tabIndex: 0,
              selectedOptions: [firstOption]
            });
            _context.next = 9;
            return sleep();

          case 9:
            wrapper.find('.rc-cascader__options').at(1).find('.rc-cascader__option').simulate('click');
            secondOption = options[0].children[0];
            expect(onChange.mock.calls[1][0]).toEqual({
              value: secondOption.value,
              tabIndex: 1,
              selectedOptions: [firstOption, secondOption]
            });

          case 12:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('will not emit onChange event when using disalbed prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    var items, onChange;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            items = [{
              text: '广东省',
              value: '310000',
              children: [{
                text: '深圳市',
                value: '310100'
              }],
              disabled: true
            }];
            onChange = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
              options: items,
              onChange: onChange
            }));
            _context2.next = 5;
            return sleep();

          case 5:
            wrapper.find('.rc-cascader__option').at(0).simulate('click');
            expect(onChange).not.toHaveBeenCalled();

          case 7:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should emit finish event when all options is selected', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    var option, onFinish;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            option = {
              value: '1',
              text: 'foo'
            };
            onFinish = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
              options: [option],
              onFinish: onFinish
            }));
            _context3.next = 5;
            return sleep();

          case 5:
            wrapper.find('.rc-cascader__option').simulate('click');
            expect(onFinish.mock.calls[0][0]).toEqual({
              value: option.value,
              tabIndex: 0,
              selectedOptions: [option]
            });

          case 7:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should emit close event when close icon is clicked', function () {
    var onClose = jest.fn();
    wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
      onClose: onClose
    }));
    wrapper.find(Icon).props().onClick();
    expect(onClose).toHaveBeenCalled();
  });
  it('should not render close icon when closeable is false', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
      closeable: false
    }));
    expect(wrapper.find('.rc-cascader__close-icon').exists()).toBeFalsy();
  });
  it('should change close icon when close-icon prop is string', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
      closeIcon: "success"
    }));
    expect(wrapper.find(Icon).props().name).toEqual('success');
  });
  it('should change close icon when close-icon is ValidElement', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
      closeIcon: /*#__PURE__*/React.createElement(Icon, {
        name: "shop-o"
      })
    }));
    expect(wrapper.find('i.van-icon-shop-o').exists()).toBeTruthy();
  });
  it('should change close icon when close-icon is not ValidElement', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
      closeIcon: 123
    }));
    expect(wrapper.find('i.van-icon-shop-o').exists()).toBeFalsy();
  });
  test('should render title slot correctly', function () {
    wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
      title: "Custom Title"
    }));
    expect(wrapper.find('.rc-cascader__title').html()).toMatchSnapshot();
  });
  test('should render option correctly when using optionRender prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    var optionItem;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            optionItem = {
              value: '1',
              text: 'foo'
            };
            wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
              options: [optionItem],
              optionRender: function optionRender(_ref5) {
                var option = _ref5.option;
                return "Custom Option ".concat(option.text);
              }
            }));
            _context4.next = 4;
            return sleep();

          case 4:
            expect(wrapper.find('.rc-cascader__option').text()).toEqual('Custom Option foo');

          case 5:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  test('should render option correctly when using defaultValue prop', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            Date.now = jest.fn(function () {
              return 1482363367071;
            });
            wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
              options: options,
              defaultValue: ['330000']
            }));
            _context5.next = 4;
            return sleep();

          case 4:
            expect(toJson(wrapper)).toMatchSnapshot();

          case 5:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  test('should emit onClickTab event correctly', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    var onClickTab;
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            onClickTab = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
              options: options,
              onClickTab: onClickTab
            })); // console.log('====onClickTab-bug===',wrapper.debug());
            // console.log('====onClickTab-html===',wrapper.html());

            _context6.next = 4;
            return wrapper.find('.rc-tab').simulate('click');

          case 4:
            expect(onClickTab).toHaveBeenCalled();

          case 5:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  test('when value change', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
    return _regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(Cascader, {
              options: options,
              defaultValue: ['330000']
            }));
            _context7.next = 3;
            return wrapper.setProps({
              value: ['350000']
            });

          case 3:
            expect(toJson(wrapper)).toMatchSnapshot();

          case 4:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
});
